
# Type: mixin


this slot or class can only be used as a mixin -- equivalent to abstract

URI: [meta:mixin](https://w3id.org/biolink/biolinkml/meta/mixin)


## Domain and Range

[Definition](Definition.md) ->  <sub>OPT</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)
